pub struct ClientConnectionManager<S> { /* private fields */ }Expand description
Struct to help implementing pooling with bb8
TODO
- Move the cache out of the Client struct so we can share the cache across all connections in the pool
Implementations
Sourceimpl<S: MembershipStorage + 'static> ClientConnectionManager<S>
impl<S: MembershipStorage + 'static> ClientConnectionManager<S>