ClientError

Enum ClientError 

pub enum ClientError {
    NoServersAvailable,
    ServerNotAvailable(String),
    Disconnect,
    RendevouzUnavailable,
    Connectivity,
    Unknown(String),
    PlacementLock,
    DeseralizationError(String),
    SeralizationError(String),
    IoError(String),
}
Errors that might occur while building or using the client, but that are not related to any behaviour on the server

Variants



NoServersAvailable



ServerNotAvailable(String)



Disconnect



RendevouzUnavailable



Connectivity



Unknown(String)



PlacementLock



DeseralizationError(String)



SeralizationError(String)



IoError(String)