SubscriptionRequest

Struct SubscriptionRequest 

pub struct SubscriptionRequest {
    pub handler_type: String,
    pub handler_id: String,
}
This is the struct that we serialize and send to the server serialized to request a new subscription

Fields

handler_type: Stringhandler_id: String