pub type SendCommandResult = Result<Vec<u8>, ResponseError>;Expand description
Result for the internal client interface on the server
Aliased Type
pub enum SendCommandResult {
Ok(Vec<u8>),
Err(ResponseError),
}pub type SendCommandResult = Result<Vec<u8>, ResponseError>;Result for the internal client interface on the server
pub enum SendCommandResult {
Ok(Vec<u8>),
Err(ResponseError),
}