pub struct SubscriptionRequest {
pub handler_type: String,
pub handler_id: String,
}Expand description
This is the struct that we serialize and send to the server serialized to request a new subscription
Fields
handler_type: Stringhandler_id: StringTrait Implementations
Sourceimpl Debug for SubscriptionRequest
impl Debug for SubscriptionRequest
Sourceimpl<'de> Deserialize<'de> for SubscriptionRequest
impl<'de> Deserialize<'de> for SubscriptionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for SubscriptionRequest
impl Serialize for SubscriptionRequest
Sourceimpl<S, P> Service<SubscriptionRequest> for Service<S, P>where
S: MembershipStorage + 'static,
P: ObjectPlacement + 'static,
Service implementation to handle SubscriptionRequest messages
impl<S, P> Service<SubscriptionRequest> for Service<S, P>where
S: MembershipStorage + 'static,
P: ObjectPlacement + 'static,
Service implementation to handle SubscriptionRequest messages
Sourcetype Response = SubscriptionResponseIter
type Response = SubscriptionResponseIter
Responses given by the service.
Sourcetype Error = ResponseError
type Error = ResponseError
Errors produced by the service.
Sourcetype Future = Pin<Box<dyn Future<Output = Result<<Service<S, P> as Service<SubscriptionRequest>>::Response, <Service<S, P> as Service<SubscriptionRequest>>::Error>> + Send>>
type Future = Pin<Box<dyn Future<Output = Result<<Service<S, P> as Service<SubscriptionRequest>>::Response, <Service<S, P> as Service<SubscriptionRequest>>::Error>> + Send>>
The future response value.